#' ---
#' title: "Supporting Online Material 7:\\ statistical analyses in Witzlack-Makarevich et al. (2016) _Decomposing ..._"
#' author: "Balthasar Bickel"
#' date: "`r format(Sys.time(), '%B %e, %Y')`"
#' output:
#'  pdf_document:
#'   fig_crop: true
#'   fig_caption: true
#'   latex_engine: xelatex
#'   toc: true
#'   toc_depth: 4
#'   number_section: true
#'   pandoc_args: [
#'   "--variable=lof",
#'   "--bibliography=/Users/balthasar/SWITCHdrive/Bibliographies/repo/bbbib.bib",
#'   "--csl=/Users/balthasar/SWITCHdrive/Bibliographies/repo/unified-style-linguistics.csl",
#'   ]
#' ---

#+ setup, include=F
require(knitr)
require(dplyr)
require(tidyr)
require(ape)
require(phytools)
require(mvMORPH)
require(qvalue)

knit_hooks$set(crop = hook_pdfcrop, pars = function(before, options, envir) {if(before) {par(family=my.font)} else NULL}) # trick for keeping par across chunks; define my.font below!

opts_chunk$set(fig.path='som-figures/',
	       	dev = 'cairo_pdf', dev.args=list(bg='transparent'), 
                fig.height = 7,
                fig.width = 14,
                message = F,
                warning = F,
	        autodep=T,
	      	cache.comments=F,
	      	crop=T,
		pars=T
	      	)

# graphics setup:
my.font = 'Linux Libertine'
plot.cex=1.3

options(width=180)

#' \clearpage
#'
#' Data
#' ====
#'
#' The Kiranti data are sometimes split into paradigms. We treat each paradigm as an independent  diachronic trial (a particular instance of morphological evolution), as explained in the main paper. Therefore, we split the data into a set of past tense and a set of nonpast tense paradigms, assuming that the two sets reflect independent histories. Where there is no difference between the two paradigms with regard to the rankings, we take the same count data for both past and non-past paradigms.
#'
#' In addition, we also include sets where the two paradigms are combined so that we can fit models assuming correlations and interactions between the paradigms. For the set-based method, a suitable format for this is one in which the paradigms of a language are coded as if they were two off-shoots of that language (`kir.data.all`). For the tree-based method, we store the counts per ranking per paradigm as two variables per language (`kir.data.corr` below, after further data preparation steps).

kir.data <- read.csv('som4_KirantiAggregated.csv', header=T,check.names=F)

kir.data.npst <- subset(kir.data, grepl('NPST', TAM) | grepl('_IND', TAM) | grepl('^IND', TAM)) %>%
  select(-TAM)
kir.data.pst <- subset(kir.data, grepl('_PST', TAM) | grepl('_IND', TAM) | grepl('^IND', TAM)) %>%
  select(-TAM)

kir.data.all <- kir.data %>% mutate(language=paste(language, gsub('\\d*_*','',TAM))) %>%
   select(-TAM)

alg.data <- read.csv('som3_AlgonquianAggregated.csv', header=T,check.names=F)

#' For each family, we generate a list of rankings. Each  element of this list is a `data.frame` reporting the proportion in which the ranking is attested in each language. If there is a zero count, we interpret this as no evidence for the ranking. This is then reported as a .5 probability for either ranking.
#'
#' For the tree-based approach we also need arcsine square root transformations in order to allow estimates outside the [0,1] interval.

prep.data <- function(family) {
	# 1>2
	fam12 <- family[,c("language","1 > 2","2 > 1")] %>% mutate(
   		total=`2 > 1` + `1 > 2`,
   		prop.tmp= `1 > 2`/total,
   		prop=ifelse(is.nan(prop.tmp),.5, prop.tmp),
   		propt=asin(sqrt(prop))
   		) %>% select(-prop.tmp)
	# 2>1
	fam21 <- family[,c("language","2 > 1","1 > 2")] %>% mutate(
			total=`2 > 1` + `1 > 2`,
			prop.tmp= `2 > 1`/total,
			prop=ifelse(is.nan(prop.tmp),.5, prop.tmp),
			propt=asin(sqrt(prop))
			)  %>% select(-prop.tmp)
	# 1>3
	fam13 <- family[,c("language","1 > 3","3 > 1")] %>% mutate(
			total=`3 > 1` + `1 > 3`,
			prop.tmp= `1 > 3`/total,
			prop=ifelse(is.nan(prop.tmp),.5, prop.tmp),
			propt=asin(sqrt(prop))
			) %>% select(-prop.tmp)
	# 2>3
	fam23 <- family[,c("language","2 > 3","3 > 2")] %>% mutate(
			total=`2 > 3` + `3 > 2`,
			prop.tmp= `2 > 3`/total,
			prop=ifelse(is.nan(prop.tmp),.5, prop.tmp),
			propt=asin(sqrt(prop))
			) %>% select(-prop.tmp)

	list(   fam12=fam12,
		fam21=fam21,
		fam13=fam13,
		fam23=fam23
		)
	}

kir.data.all.list <- prep.data(kir.data.all)
kir.data.npst.list <- prep.data(kir.data.npst)
kir.data.pst.list <- prep.data(kir.data.pst)
alg.data.list <- prep.data(alg.data)

#' We will also look into the Western and the Central-Eastern branches of Kiranti separately. For the set-based method, this requires a split of the lists; for tree-based methods we can model the impact of the Western vs.  Central-Eastern distinction directly with the original data.
#'
#' _Western Kiranti:_
kir.w.lgs <- c('Bahing','Kõic','Dumi','Jero','Wambule', 'Koyi')
kir.w.data.all <- subset(kir.data.all,
	gsub('(.*?)\\s.*', '\\1', language) %in% kir.w.lgs)
kir.w.data.all.list <- prep.data(kir.w.data.all)
kir.w.data.npst <- subset(kir.data.npst,
	gsub('(.*?)\\s.*', '\\1', language) %in% kir.w.lgs)
kir.w.data.npst.list <- prep.data(kir.w.data.npst)
kir.w.data.pst <- subset(kir.data.pst,
	gsub('(.*?)\\s.*', '\\1', language) %in% kir.w.lgs)
kir.w.data.pst.list <- prep.data(kir.w.data.pst)

#' _Central-Eastern Kiranti:_
kir.ce.data.all <- subset(kir.data.all,
	!gsub('(.*?)\\s.*', '\\1', language) %in% kir.w.lgs)
kir.ce.data.all.list <- prep.data(kir.ce.data.all)
kir.ce.data.npst <- subset(kir.data.npst,
	!gsub('(.*?)\\s.*', '\\1', language) %in% kir.w.lgs)
kir.ce.data.npst.list <- prep.data(kir.ce.data.npst)
kir.ce.data.pst <- subset(kir.data.pst,
	!gsub('(.*?)\\s.*', '\\1', language) %in% kir.w.lgs)
kir.ce.data.pst.list <- prep.data(kir.ce.data.pst)

#' The following loop creates the input for correlated evolution models. It creates a list of rankings where each ranking consists of a matrix with columns for NPST and PST proportions and rows for the languages. (We focus on the transformed proportions only.) Where there is no difference between the paradigms in a language, this means that NPST and PST have the same values. For Dumi and Chintang, the database happens to lack the entries, creating NAs (which don't pose a problem for model fitting).

kir.data.corr <- lapply(kir.data.all.list, function(f) {
	f[,-c(2:5)]  %>% 
	separate(language, c('language', 'paradigm'), sep=" ")  %>%
	spread(paradigm, propt) %>%
        mutate( # if there is no difference, it's the same values:
	       NPST.IND=ifelse(is.na(NPST.IND), IND, NPST.IND),
      	       PST.IND=ifelse(is.na(PST.IND), IND, PST.IND)
              ) %>%
        select(-IND) -> x
        m <- as.matrix(x[,-1]) 
	# when adding the names we also fix the name Limbu so it will match the tip label in the tree:
	dimnames(m)[[1]] <- gsub('Limbu','Phedappe_Limbu', x$language)  
	return(m)  
	})

#' 
#'
#' Trees
#' =====
#'
#' _Kiranti:_
kir.tree <- collapse.singles(read.newick(text="((((Kulung:1)Khambu:1,(Camling:1,Puma:1,Bantawa:1)Southern_Kiranti:1)Central_Kiranti:1,(((Belhare:1,Athpare:1,Chintang:1)Greater_Yakkha:1,(Phedappe_Limbu:1)Limbu:1)Yakkha-Limbu:1,(Yamphu:1,Lohorung:1)Upper_Arun:1)Eastern_Kiranti:1)Central-Eastern_Kiranti:1,((Wambule:1,Jero:1)Chaurasiya:1,(Kõic:1,Bahing:1)Northwestern_Kiranti:1,(Dumi:1)Upper_Dudhkosi:1)Western_Kiranti:1,(Koyi:1)Midwestern_Kiranti:1)Kiranti:1;"))

#+ kir-tree-plot, fig.cap="Kiranti"
par(family=my.font, lheight=1, cex=plot.cex)
kir.tree.print <- rotate(kir.tree, node=18)
plot(kir.tree.print, no.margin=T, font=1,  label.offset =.02)
nodelabels(gsub("_", " \n", kir.tree.print$node.label[-1]), 
           node=18:27, bg='white', cex=plot.cex-.2)

#' _Algonquian_, in two versions:
alg.tree <- collapse.singles(read.newick(text='((Cheyenne:1):1,(Blackfoot:1)Siksika:1,(Arapaho:1)Arapahoic:1,(Plains_Cree:1)Cree-Montagnais-Naskapi:1,(Eastern_Ojibwa:1)Eastern_Great_Lakes:1,(Munsee:1,Micmac:1,Passamaquoddy:1)Eastern_Algonquian:1)Algonquian:1;'))

alg.alt.tree <- collapse.singles(read.newick(text="((Blackfoot:1)Siksika:1,((Arapaho:1)Arapahoic:1,(Plains_Cree:1)Cree-Montagnais-Naskapi:1,(Cheyenne:1,((Eastern_Ojibwa:1)Eastern_Great_Lakes:1,(Munsee:1,Micmac:1,Passamaquoddy:1)EasternAlgonquian:1)Group3:1)Group2:1)Group1:1)Algonquian:1;"))

#+ alg-tree-plot, fig.cap="Algonquian, traditional genealogy"
par(family=my.font, lheight=.2, cex=plot.cex)
plot(alg.tree, no.margin=T, font=1,  label.offset =.02)
nodelabels(text='\nEastern Algonquian \n', 
           node=10, bg='white', cex=plot.cex-.2)

#+ alg-alt-tree-plot, fig.cap="Algonquian, alternative genealogy"
par(family=my.font, lheight=.2, cex=plot.cex)
plot(alg.alt.tree, no.margin=T, font=1, label.offset =.02)
nodelabels(text=c('1 ', '2 ', '3 ', '\nEastern Algonquian \n'), 
	   node=10:13, bg='white', cex=plot.cex-.2)

#' \clearpage
#'
#' Set-based models
#' ================
#'
#' Here we first test for each language whether or not the count of cases favoring the ranking is greater than what would be expected under a Bernoulli process assuming equal probablity ($H_0$). If there is a zero count for a given ranking, we report this as $p=1$:

binom.test.proc <- function(fam.data.list) {
	lapply(fam.data.list, function(r) {
		apply(r[,c(2,4)], 1, function(b) {
	   		ifelse(b[2]>0,
	   			binom.test(x=b[1], n=b[2], alternative='greater')$p.value,
	   			1)
			})
		})
	}

#' From this we compute the proportion of languages (or paradigms) for which a given ranking is significantly preferred. In order to control for inflated evidence resulting from multiple testing, we correct p-values via Holm's procedure [@Holm1979A-simple]. As an alternative, we also tried false discovery control (with a 10% threshold) using the `qvalue` package [@Storeyetal2015qvalue], but the results were the same.

prop.sig <- function(fam.list, sig, q)	{
	round(sapply(fam.list, function(r) { mean(p.adjust(r, method='holm')<sig)
					   # qs <- qvalue(r, pi0.method="bootstrap")$qvalues
					   # results <- data.frame(ps=r, qs=qs)
					   # with(results, mean(qs<q & ps<sig))
					   }
			), 2)
	}

list.of.lists <- c(kir.data.all.list,
		  kir.w.data.all.list,
		  kir.ce.data.all.list,
		  kir.data.npst.list,
		  kir.w.data.npst.list,
		  kir.ce.data.npst.list,
		  kir.data.pst.list,
		  kir.w.data.pst.list,
		  kir.ce.data.pst.list,
		  alg.data.list)

combine <- function(list.of.lists, sign, q) {
	matrix(prop.sig(binom.test.proc(list.of.lists), sig=sign), ncol=4, byrow=T, 
		dimnames=list(c('Kiranti (all)', 'Western Kiranti (all)',
	   	  'Central-Eastern Kiranti (all)',
  		  'Kiranti (NPST)', 'Western Kiranti (NPST)', 'Central-Eastern Kiranti (NPST)',
		  'Kiranti (PST)', 'Western Kiranti (PST)', 'Central-Eastern Kiranti (PST)',
		  'Algonquian'
		  ), c("1>2", "2>1", "1>3","2>3")
		  ))
		  }

#' \clearpage
#' 
combine(list.of.lists, sign=.05, q=.1)


#' \clearpage
#'
#' Tree-based models
#' =================
#'
#' We compare Ornstein-Uhlenbeck (‘OU’) to Brownian Motion (‘BM’) models using likelihood ratio tests and sample-size corrected AICs (`AICc` below), following @Butleretal2004Phylogenetic. A Brownian Motion model is a special kind of Wiener process (_W_) or random walk, where the values of a trait evolve randomly with diffusion intensity $\sigma$, or in terms of a stochastic differential equation for trait X over continuous time _t_: $\mathrm{d}X(t) = \sigma\mathrm{d}W(t)$. An Ornstein-Uhlenbeck model constrains this further by a drift to an optimum value $\theta$, towards which the process is attracted with strength $\alpha$: $\mathrm{d}X(t) = \alpha[\theta - X(t)]\mathrm{d}t + \sigma\mathrm{d}W(t)$ [@Butleretal2004Phylogenetic].
#' 
#' The models are fitted with the `mvBM` and `mvOU` functions from package `mvMORPH` [@Clavel2015mvMORPH]. Note that `mvOU` generates both a root and an optimum ($\theta$ in the equation) estimate in the object `theta` but when there is no root, `theta` simplifies to the optimum estimate alone. We catch this in the code below by checking the number of rows in `theta`. (The root estimates themselves are not reliable with these data and of no interest.)
#' 
#' To allow different trait histories in Western vs. Central-Eastern Kiranti (via the `groups` parameter in the code below), we first generate trees with a character state map produced by `phytools::make.simmap` [@Revell2012phytools]. For this, we assume that transitions between the groups are equally likely (‘equal rates’ or ‘ER’ model). The mapping is stochastic, so in principle one could sample from a series of mappings that would differ in where exactly along the branches the languages group into Western vs. Central-Eastern. However, as we use the mapping only as a control for possible multiple optima, it does not matter where and when the grouping really took place. Therefore, we pick whichever mapping happens to fall out (as in @Clavel2015mvMORPH, appendix). For illustration of a mapping, see below when we report the results from Kiranti.
#' 
#' Models with different histories (`OU2` below) are compared to models with a single history (`OU1`) by likelihood ratio tests (reported as `LR.OU2` below) and a sample-size corrected version of Akaike's An Information Criterion, AIC$_c$ (`AICc`).
#' 
#' ***Single-trait evolution models:***
#' 

tree.test.proc <- function(fam.data.list, fam.tree, groups=NULL, transformed=T) {
   do.call(rbind,
	lapply(seq_along(fam.data.list), function(i) {

	ranking <- gsub('.*(\\d)(\\d)', '\\1 > \\2', names(fam.data.list)[[i]])

	fam.data <- fam.data.list[[i]]

	mean.prop <- mean(fam.data$prop)
	sd.prop <- sd(fam.data$prop)

	if(transformed) {
		# use the arcsine-sqrt values available in "propt"
		fam.data <- setNames(fam.data$propt, fam.data$language)
		} else {
		fam.data <- setNames(fam.data$prop, fam.data$language)
		}

	bm <- mvBM(fam.tree, fam.data, model='BM1', echo=F, diagnostic=F)
	ou1 <- mvOU(fam.tree, fam.data, model='OU1', echo=F, diagnostic=F)

	if(!is.null(groups)) {
		# map the groups onto the tree
		fam.tree.maps <- make.simmap(fam.tree, groups, model='ER', message=F)
		# and fit a model allowing different selective regimes per group:
	  	ou2 <- mvOU(fam.tree.maps, fam.data, model='OUM', echo=F, diagnostic=F)
		}

 	# Likelihood ratio test and sample-size corrected AIC:
	LR.OU1 <- 2 * (ou1$LogLik - bm$LogLik)
	df.OU1 <-  ou1$param$nparam - bm$param$nparam
	p.OU1 <- pchisq(LR.OU1, df = df.OU1, lower.tail = F)
	AICc.BM <- bm$AICc	
	AICc.OU1 <-  ou1$AICc	

	if(!is.null(groups)) {
	  	LR.OU2 <- 2 * (ou2$LogLik - ou1$LogLik)
		df.OU2 <- ou2$param$nparam - ou1$param$nparam
	  	p.OU2 <- pchisq(LR.OU2, df = df.OU2, lower.tail = F)
		AICc.OU2 <- ou2$AICc	
		}

	# Model parameters:
	param.est <- data.frame(
		BM.sigma= bm$sigma,
		OU1.theta = ifelse(nrow(ou1$theta)==1, # if there is no separate root estimate:
				ou1$theta,
				# else, the theta parameter is in the second row:
				ou1$theta[2,1]),
		OU1.alpha= ou1$alpha[1,1],
		OU1.sigma= ou1$sigma[1,1]
		)

	if(!is.null(groups)) {
	  	param.est <- cbind(param.est, OU2.alpha=ou2$alpha[1,1],
		  		              OU2.sigma= ou2$sigma[1,1])
		# get the OUM parameters
		theta2 <- ou2$theta[-1,]
	  	names(theta2) <- paste0('OU2.theta_', names(theta2))
		# and add them as columns:
		param.est <- cbind(param.est, data.frame(t(theta2)))
		}

	if(transformed) {
		# transform all parameters back from the arcine sqrt transformation:
		param.est <- t(apply(param.est, 1, function(r) sin(r)^2))
		}

	param.est <- t(apply(param.est, 1, round, 4))

	if(!is.null(groups)) {
	  means <- data.frame(t(tapply(fam.data, groups, function(i) round(mean(i),2))))
	  names(means) <- paste0('m_', names(means))
	  sds <- data.frame(t(tapply(fam.data, groups, function(i) round(sd(i),2))))
	  names(sds) <- paste0('sd_', names(sds))
	  data.frame(row.names=ranking,
		     means, sds,
  		     LR.OU1=round(LR.OU1, 2), p.OU1=round(p.OU1, 4), df.OU1=df.OU1,
		     LR.OU2=round(LR.OU2, 2), p.OU2=round(p.OU2, 4), df.OU2=df.OU2,
		     AICc.BM=round(AICc.BM, 2), AICc.OU1=round(AICc.OU1,2),
		     	 			AICc.OU2=round(AICc.OU2,2),
		     param.est)
		  } else {
	  colnames(param.est) <- gsub('1','', colnames(param.est))
	  data.frame(row.names=ranking,
		     m.prop=round(mean.prop,2), sd.prop=round(sd.prop,2),
		     LR.OU=round(LR.OU1, 2), p.OU=round(p.OU1, 4), df.OU=df.OU1,
		     AICc.BM=round(AICc.BM, 2), AICc.OU=round(AICc.OU1,2),
		     Red=round((AICc.OU1-AICc.BM),2),
		     param.est)
	  	}
	}
	))
	}
#' 
#' ***Correlated evolution models (Kiranti only):***
#' 
#' These are models that assume a correlation between the proportions in the two paradigms, yielding a larger number of parameters to estimate. Following @Clavel2015mvMORPH, we rely on sample-sized corrected AIC comparison (`AICc`) exclusively here.

tree.corr.test.proc <- function(fam.data.list=kir.data.corr, fam.tree=kir.tree, groups=NULL) {

	kir.corr.res <- lapply(seq_along(fam.data.list), function(i) {

	fam.data <- kir.data.corr[[i]]

	bm <- mvBM(fam.tree, fam.data, model='BM1',  echo=F, diagnostic=F)
	ou1 <- mvOU(fam.tree, fam.data, model='OU1', echo=F, diagnostic=F)
	
	if(!is.null(groups)) {
		# map the groups onto the tree
		fam.tree.maps <- make.simmap(fam.tree, groups, model='ER', message=F)
		# and fit a model allowing different selective regimes per group:
	  	ou2 <- mvOU(fam.tree.maps, fam.data, model='OUM', echo=F, diagnostic=F)
		}
	
	# because of the complex output, we don't force a data.frame summary here
	param.est <- list(
		BM.sigma= bm$sigma,
		OU.theta = ou1$theta[2, ], # we don't need the root in row 1
		OU.alpha= ou1$alpha,
		OU.sigma= ou1$sigma
		)
		
	if(!is.null(groups)) {
	  	param.est <- c(param.est, list(OU2.alpha=ou2$alpha,
		  		               OU2.sigma= ou2$sigma,
					       OU2.theta=ou2$theta[-1,]
					  )
			      )	  
		}
		
	res <- list(AICc=data.frame(BM=round(bm$AICc,2), OU=round(ou1$AICc,2)),
	     	    parameters=lapply(param.est, function(p) sin(p)^2),
	     	    corr=cov2cor(stationary(ou1))
	            )

	if(!is.null(groups)) {
		res <- list(AICc=data.frame(BM=round(bm$AICc,2), OU1=round(ou1$AICc,2),
		                            OU2=round(ou2$AICc, 2)),
		     parameters=lapply(param.est, function(p) sin(p)^2),
		     corr.ou1=cov2cor(stationary(ou1)),
		     corr.ou2=cov2cor(stationary(ou2))
		     )
		}
	return(res)	     
	}
	)
	}

#'
#' Kiranti
#' -------
#'
#' We first need to fix the language names in the data list so that they match what's in the tree:
kir.data.npst.list.fixed <- lapply(kir.data.npst.list, function(l) {
	l$language <- gsub('Limbu','Phedappe_Limbu', l$language)
	return(l)
	})
kir.data.pst.list.fixed <- lapply(kir.data.pst.list, function(l) {
	l$language <- gsub('Limbu','Phedappe_Limbu', l$language)
	return(l)
	})
#' 
#' 
#' 
#' ### Constant evolution over the entire tree
#' 
#' Here we assume a single selection regime over the entire tree, i.e. we assume that the parameters of Ornstein-Uhlenbeck model are the same throughout and paradigms evolve towards the optimum value during the history of the entire family.
#' 
#' #### Non-Past Paradigms
(kir.npst.res.trees <- tree.test.proc(kir.data.npst.list.fixed, kir.tree))

#' 
#' #### Past Paradigms
#' 
#' For testing these paradigms we need to drop Dumi and Chintang because we happen to lack the data in the database:
kir.tree.reduced <- drop.tip(kir.tree, tip=c('Dumi', 'Chintang'))
(kir.pst.res.trees <- tree.test.proc(kir.data.pst.list.fixed, kir.tree.reduced))

#' 
#' #### Correlated evolution of the two paradigms
#' 
#+ kir-corr, cache=T
kir.corr.res <- tree.corr.test.proc()
#' _AIC$_c$ comparison:_
kir.corr.res.aiccs <- do.call(rbind, sapply(kir.corr.res, "[", 1))
rownames(kir.corr.res.aiccs) <- gsub('.*(\\d)(\\d)', '\\1 > \\2', names(kir.data.corr))
kir.corr.res.aiccs

#' 
#'
#' ### Non-constant evolution, with possible changes in Western and Central-Eastern Kiranti
#'
#' For this we map the Western vs Central-Eastern group distinction to the tree, as explained above. 
n.west <- length(kir.w.lgs)
groups <- c(rep('Central-Eastern', length(kir.tree$tip.label)-n.west), rep('Western', n.west))
names(groups) <- kir.tree$tip.label
#' Here is how the mapping is done, and Fig. 4 below is an illustration of the result:
kir.tree.maps <- make.simmap(kir.tree, groups, model='ER')
#+ simmap, echo=F, fig.cap='The Western vs Central-Eastern distinction mapped on the tree as evolutionary constraints'
col <- c('blue', 'red'); names(col) <- c('Central-Eastern', 'Western')
plotSimmap(kir.tree.maps, col, fsize=plot.cex)

#' \clearpage
#' 
#' #### Non-Past Paradigms
#' 
kir.npst.res.trees.m <- tree.test.proc(kir.data.npst.list.fixed, kir.tree, groups=groups)
#' 
#' _Descriptives:_
#+ echo=F
kir.npst.res.trees.m[,1:4]
#' _LR tests and AIC$_c$ comparison_: `LR.OU1` and `p.OU1` report a comparison with BM; `LR.OU2` and `pOU2` report a comparison with `OU1` (i.e. whether a model with flexible histories (`OU2`) fits better than one with a single history (`OU1`))
#+ echo=F
kir.npst.res.trees.m[,5:13]
#' _Model parameters:_
#+ echo=F
kir.npst.res.trees.m[,14:19]
kir.npst.res.trees.m[,20:ncol(kir.npst.res.trees.m)]

#' 
#' 
#' #### Past Paradigms
#' 
groups.reduced <- groups[!names(groups) %in% c('Dumi', 'Chintang')]
kir.pst.res.trees.m <- tree.test.proc(kir.data.pst.list.fixed, kir.tree.reduced, groups=groups.reduced)
#' 
#' _Descriptives:_
#+ echo=F
kir.pst.res.trees.m[,1:4]
#' \clearpage
#' _LR tests and AIC$_c$ comparison_: `LR.OU1` and `p.OU1` report a comparison with BM; `LR.OU2` and `pOU2` report a comparison with `OU1` (i.e. whether a model with flexible histories (`OU2`) fits better than one with a single history (`OU1`))
#+ echo=F
kir.pst.res.trees.m[,5:13]
#' _Model parameters:_
#+ echo=F
kir.pst.res.trees.m[,14:19]
kir.pst.res.trees.m[,16:ncol(kir.pst.res.trees.m)]

#' 
#' #### Correlated evolution of the two paradigms
#' 
#' _AIC$_c$ comparison:_ `OU1` is a model with a single history, `OU2` one with flexible histories:
#+ kir-corr-m, cache=T
kir.corr.res.m <- tree.corr.test.proc(groups=groups)
kir.corr.res.aiccs.m <- do.call(rbind, sapply(kir.corr.res.m, "[", 1))
rownames(kir.corr.res.aiccs.m) <- gsub('.*(\\d)(\\d)', '\\1 > \\2', names(kir.data.corr))
kir.corr.res.aiccs.m


#'
#' Algonquian
#' ----------
#' We need to fix the language names in the tree so that they match what's in the data list:

alg.tree$tip.label <- with(alg.tree, ifelse(tip.label %in% 'Plains_Cree', 'Cree (Plains)',
 			ifelse(tip.label %in% 'Eastern_Ojibwa', 'Ojibwa (Eastern)', tip.label)))
alg.alt.tree$tip.label <- with(alg.alt.tree, ifelse(tip.label %in% 'Plains_Cree', 'Cree (Plains)',
	 		ifelse(tip.label %in% 'Eastern_Ojibwa', 'Ojibwa (Eastern)', tip.label)))

#' Flat tree (as in Figure 2)
(alg.res.trees <- tree.test.proc(alg.data.list, alg.tree))

#' Alternative, more structured tree (as in Figure 3)
(alg.alt.res.trees <- tree.test.proc(alg.data.list, alg.alt.tree))


#'
#' References
#' ==========
#'


